Nonlinear Eigenvalue Problem Solvers - NEP

slepc-3.18.0 2022-10-01
Report Typos and Errors

## Nonlinear Eigenvalue Problem Solvers - NEP: Examples NLEVP

The Nonlinear Eigenvalue Problem (NEP) solver is the object provided by SLEPc for specifying an eigenvalue problem that is nonlinear with respect to the eigenvalue (not the eigenvector). This is intended for general nonlinear problems (rather than polynomial eigenproblems) described as T(λ)x=0.

As in the other solver objects, users can set various options at runtime via the options database (e.g., `-nep_nev 4 -nep_type narnoldi`). Options can also be set directly in application codes by calling the corresponding routines (e.g., NEPSetDimensions() / NEPSetType()).

interpol.c
makefile